==> pm4py-2.2.15.1.tar.gz: pm4py-2.2.15.1/README.THIRD_PARTY.md <==
# PM4Py Third Party Dependencies

PM4Py depends on third party libraries to implement some functionality. This document describes which libraries
PM4Py depends upon. This is a best effort attempt to describe the library's dependencies, it is subject to change as
libraries are added/removed.

| Name | URL | License | Version |
| --------------------------- | ------------------------------------------------------------ | --------------------------- | ------------------- |
| backcall | https://pypi.org/project/backcall | BSD License | 0.2.0 |
| colorama | https://pypi.org/project/colorama | BSD License (BSD) | 0.4.4 |
| cvxopt | https://pypi.org/project/cvxopt | GNU General Public License v3 (GPLv3) (GNU GPL version 3) | 1.2.6 |
| cycler | https://pypi.org/project/cycler | BSD | 0.10.0 |
| decorator | https://pypi.org/project/decorator | BSD License (new BSD License) | 5.1.0 |
| deprecation | https://pypi.org/project/deprecation | Apache Software License (Apache 2) | 2.1.0 |
| fonttools | https://pypi.org/project/fonttools | MIT License (MIT) | 4.27.1 |
| graphviz | https://pypi.org/project/graphviz | MIT License (MIT) | 0.17 |
| intervaltree | https://pypi.org/project/intervaltree | Apache Software License (Apache License, Version 2.0) | 3.1.0 |
| ipython | https://pypi.org/project/ipython | BSD License (BSD) | 7.28.0 |
| jedi | https://pypi.org/project/jedi | MIT License (MIT) | 0.18.0 |
| jinja2 | https://pypi.org/project/jinja2 | BSD License (BSD-3-Clause) | 3.0.2 |
| joblib | https://pypi.org/project/joblib | BSD License (BSD) | 1.1.0 |
| jsonpickle | https://pypi.org/project/jsonpickle | BSD License | 2.0.0 |
| kiwisolver | https://pypi.org/project/kiwisolver | BSD License (BSD) | 1.3.2 |
| lxml | https://pypi.org/project/lxml | BSD License (BSD) | 4.6.3 |
| MarkupSafe | https://pypi.org/project/MarkupSafe | BSD License (BSD-3-Clause) | 2.0.1 |
| matplotlib | https://pypi.org/project/matplotlib | Python Software Foundation License (PSF) | 3.4.3 |
| matplotlib-inline | https://pypi.org/project/matplotlib-inline | BSD 3-Clause | 0.1.3 |
| mpmath | https://pypi.org/project/mpmath | BSD License (BSD) | 1.2.1 |
| networkx | https://pypi.org/project/networkx | BSD License | 2.6.3 |
| numpy | https://pypi.org/project/numpy | BSD License (BSD) | 1.21.2 |
| packaging | https://pypi.org/project/packaging | Apache Software License, BSD License (BSD-2-Clause or Apache-2.0) | 21.0 |
| pandas | https://pypi.org/project/pandas | BSD License (BSD-3-Clause) | 1.3.3 |
| parso | https://pypi.org/project/parso | MIT License (MIT) | 0.8.2 |
| pickleshare | https://pypi.org/project/pickleshare | MIT License (MIT) | 0.7.5 |
| pillow | https://pypi.org/project/pillow | Historical Permission Notice and Disclaimer (HPND) (HPND) | 8.3.2 |
| prompt-toolkit | https://pypi.org/project/prompt-toolkit | BSD License | 3.0.20 |
| pulp | https://pypi.org/project/pulp | BSD License | 2.1 |
| pydotplus | https://pypi.org/project/pydotplus | MIT License (UNKNOWN) | 2.0.2 |
| pygments | https://pypi.org/project/pygments | BSD License (BSD License) | 2.10.0 |
| pyparsing | https://pypi.org/project/pyparsing | MIT License (MIT License) | 2.4.7 |
| python-dateutil | https://pypi.org/project/python-dateutil | Apache Software License, BSD License (Dual License) | 2.8.2 |
| pytz | https://pypi.org/project/pytz | MIT License (MIT) | 2021.3 |
| pyvis | https://pypi.org/project/pyvis | BSD | 0.1.9 |
| scikit-learn | https://pypi.org/project/scikit-learn | OSI Approved (new BSD) | 1.0 |
| scipy | https://pypi.org/project/scipy | BSD License (BSD) | 1.7.1 |
| setuptools | https://pypi.org/project/setuptools | MIT License | 58.2.0 |
| setuptools-scm | https://pypi.org/project/setuptools-scm | MIT License (MIT) | 6.3.2 |
| six | https://pypi.org/project/six | MIT License (MIT) | 1.16.0 |
| sortedcontainers | https://pypi.org/project/sortedcontainers | Apache Software License (Apache 2.0) | 2.4.0 |
| stringdist | https://pypi.org/project/stringdist | MIT License (MIT) | 1.0.9 |
| sympy | https://pypi.org/project/sympy | BSD License (BSD) | 1.9 |
| threadpoolctl | https://pypi.org/project/threadpoolctl | BSD License (BSD-3-Clause) | 3.0.0 |
| tomli | https://pypi.org/project/tomli | MIT License | 1.2.1 |
| tqdm | https://pypi.org/project/tqdm | MIT License, Mozilla Public License 2.0 (MPL 2.0) (MPLv2.0, MIT Licences) | 4.62.3 |
| traitlets | https://pypi.org/project/traitlets | BSD License (BSD) | 5.1.0 |
| wcwidth | https://pypi.org/project/wcwidth | MIT License (MIT) | 0.2.5 |

==> pm4py-2.2.17.1.tar.gz: pm4py-2.2.17.1/README.THIRD_PARTY.md <==
# PM4Py Third Party Dependencies

PM4Py depends on third party libraries to implement some functionality. This document describes which libraries
PM4Py depends upon. This is a best effort attempt to describe the library's dependencies, it is subject to change as
libraries are added/removed.

| Name | URL | License | Version |
| --------------------------- | ------------------------------------------------------------ | --------------------------- | ------------------- |
| backcall | https://pypi.org/project/backcall | BSD License | 0.2.0 |
| colorama | https://pypi.org/project/colorama | BSD License (BSD) | 0.4.4 |
| cycler | https://pypi.org/project/cycler | BSD License (BSD) | 0.11.0 |
| decorator | https://pypi.org/project/decorator | BSD License (new BSD License) | 5.1.0 |
| deprecation | https://pypi.org/project/deprecation | Apache Software License (Apache 2) | 2.1.0 |
| fonttools | https://pypi.org/project/fonttools | MIT License (MIT) | 4.28.3 |
| graphviz | https://pypi.org/project/graphviz | MIT License (MIT) | 0.19 |
| intervaltree | https://pypi.org/project/intervaltree | Apache Software License (Apache License, Version 2.0) | 3.1.0 |
| ipython | https://pypi.org/project/ipython | BSD License (BSD) | 7.30.1 |
| jedi | https://pypi.org/project/jedi | MIT License (MIT) | 0.18.1 |
| jinja2 | https://pypi.org/project/jinja2 | BSD License (BSD-3-Clause) | 3.0.3 |
| joblib | https://pypi.org/project/joblib | BSD License (BSD) | 1.1.0 |
| jsonpickle | https://pypi.org/project/jsonpickle | BSD License | 2.0.0 |
| kiwisolver | https://pypi.org/project/kiwisolver | BSD License (BSD) | 1.3.2 |
| lxml | https://pypi.org/project/lxml | BSD License (BSD) | 4.6.4 |
| MarkupSafe | https://pypi.org/project/MarkupSafe | BSD License (BSD-3-Clause) | 2.0.1 |
| matplotlib | https://pypi.org/project/matplotlib | Python Software Foundation License (PSF) | 3.5.0 |
| matplotlib-inline | https://pypi.org/project/matplotlib-inline | BSD 3-Clause | 0.1.3 |
| mpmath | https://pypi.org/project/mpmath | BSD License (BSD) | 1.2.1 |
| networkx | https://pypi.org/project/networkx | BSD License | 2.6.3 |
| numpy | https://pypi.org/project/numpy | BSD License (BSD) | 1.21.4 |
| packaging | https://pypi.org/project/packaging | Apache Software License, BSD License (BSD-2-Clause or Apache-2.0) | 21.3 |
| pandas | https://pypi.org/project/pandas | BSD License (BSD-3-Clause) | 1.3.4 |
| parso | https://pypi.org/project/parso | MIT License (MIT) | 0.8.3 |
| pickleshare | https://pypi.org/project/pickleshare | MIT License (MIT) | 0.7.5 |
| pillow | https://pypi.org/project/pillow | Historical Permission Notice and Disclaimer (HPND) (HPND) | 8.4.0 |
| prompt-toolkit | https://pypi.org/project/prompt-toolkit | BSD License | 3.0.23 |
| pydotplus | https://pypi.org/project/pydotplus | MIT License (UNKNOWN) | 2.0.2 |
| pygments | https://pypi.org/project/pygments | BSD License (BSD License) | 2.10.0 |
| pyparsing | https://pypi.org/project/pyparsing | MIT License (MIT License) | 3.0.6 |
| python-dateutil | https://pypi.org/project/python-dateutil | Apache Software License, BSD License (Dual License) | 2.8.2 |
| pytz | https://pypi.org/project/pytz | MIT License (MIT) | 2021.3 |
| pyvis | https://pypi.org/project/pyvis | BSD | 0.1.9 |
| scikit-learn | https://pypi.org/project/scikit-learn | OSI Approved (new BSD) | 1.0.1 |
| scipy | https://pypi.org/project/scipy | BSD License (BSD) | 1.7.3 |
| setuptools | https://pypi.org/project/setuptools | MIT License | 59.5.0 |
| setuptools-scm | https://pypi.org/project/setuptools-scm | MIT License (MIT) | 6.3.2 |
| six | https://pypi.org/project/six | MIT License (MIT) | 1.16.0 |
| sortedcontainers | https://pypi.org/project/sortedcontainers | Apache Software License (Apache 2.0) | 2.4.0 |
| stringdist | https://pypi.org/project/stringdist | MIT License (MIT) | 1.0.9 |
| sympy | https://pypi.org/project/sympy | BSD License (BSD) | 1.9 |
| threadpoolctl | https://pypi.org/project/threadpoolctl | BSD License (BSD-3-Clause) | 3.0.0 |
| tomli | https://pypi.org/project/tomli | MIT License | 1.2.2 |
| tqdm | https://pypi.org/project/tqdm | MIT License, Mozilla Public License 2.0 (MPL 2.0) (MPLv2.0, MIT Licences) | 4.62.3 |
| traitlets | https://pypi.org/project/traitlets | BSD License (BSD) | 5.1.1 |
| wcwidth | https://pypi.org/project/wcwidth | MIT License (MIT) | 0.2.5 |
